@@ -10,7 +10,7 @@ def convert(_dir, version, edition ='pc'):
     ret = {}
     for datum in ('recipes', 'materials', 'protocol', 'version',
             'blockCollisionShapes', 'protocolComments', 'loginPacket',
-            'commands'):
+            'commands', 'tints'):
         if datum in data:
             ret[datum] = data[datum]
     for datum in ('blocks', 'items', 'windows', 'effects', 'particles',
@@ -19,6 +19,10 @@ def convert(_dir, version, edition ='pc'):
             ret[datum] = _by_id(data[datum])
             ret[f"{datum}_name"] = _by_name(data[datum])
             ret[f"{datum}_list"] = data[datum]
+    for datum in ('blockLoot', 'entityLoot'):
+        if datum in data:
+            ret[datum] = _parse_loot(data[datum], datum)
+            ret[f"{datum}_list"] = data[datum]
     if 'entities' in data:
         ret['mobs'] = _by_id(_filter('type', 'mob', data['entities']))
         ret['objects'] = _by_id(_filter('type', 'object', data['entities']))
@@ -52,6 +56,9 @@ def _by_id(data):
 def _by_name(data):
     return _by('name', data)
 
+def _parse_loot(data, loot_string):
+    field = loot_string[:loot_string.rfind('Loot')]
+    return {d[field]: d['drops'] for d in data}
 
 def _by(key, data):
     return {item[key]: item for item in data}
